@@ -141,6 +141,8 @@
 #' covariances are generated by ctFit.  
 #' Better starting values may improve model fit speed and the chance of an appropriate model fit. 
 #' 
+#' @param silent Suppress all output to console. 
+#' 
 #' @examples 
 #'  ### Frequentist example:
 #'  ### impulse and level change time dependent predictor 
@@ -176,7 +178,7 @@
 #' @export
 
 ctModel<-function(LAMBDA, type='omx',n.manifest = 'auto', n.latent='auto', Tpoints=NULL, 
-  manifestNames='auto', latentNames='auto', id='id',time='time',
+  manifestNames='auto', latentNames='auto', id='id',time='time', silent=FALSE,
   T0VAR="auto", T0MEANS="auto", MANIFESTMEANS="auto", MANIFESTVAR="auto", 
   DRIFT="auto", CINT="auto", DIFFUSION="auto",
   n.TDpred='auto', TDpredNames='auto', 
@@ -194,12 +196,12 @@ ctModel<-function(LAMBDA, type='omx',n.manifest = 'auto', n.latent='auto', Tpoin
   #get dimensions
   if(is.null(n.manifest) || is.null(n.latent) || all(n.manifest %in% 'auto') || all(n.latent %in% 'auto')){
     if(is.matrix(LAMBDA)){
-      message('System dimensions inferred from LAMBDA')
+      if(!silent) message('System dimensions inferred from LAMBDA')
       n.manifest <- nrow(LAMBDA)
       n.latent <- ncol(LAMBDA)
     } else {
       if(!all(manifestNames %in% 'auto') && !all(latentNames %in% 'auto')){
-        message('System dimensions inferred from manifestNames and latentNames')
+        if(!silent) message('System dimensions inferred from manifestNames and latentNames')
         n.manifest <- length(manifestNames)
         n.latent <- length(latentNames)
       } else stop('LAMBDA must either a matrix, n.manifest and n.latent must be specified, or manifestNames and latentNames must be specified!')
@@ -208,11 +210,11 @@ ctModel<-function(LAMBDA, type='omx',n.manifest = 'auto', n.latent='auto', Tpoin
 
   if(is.null(n.TDpred) || all(n.TDpred %in% 'auto')){
     if(is.matrix(TDPREDEFFECT)){
-      message('n.TDpred inferred from TDPREDEFFECT')
+      if(!silent) message('n.TDpred inferred from TDPREDEFFECT')
       n.TDpred <- ncol(TDPREDEFFECT)
     } else {
       if(!all(TDpredNames %in% 'auto')){
-        message('n.TDpred inferred  inferred from TDpredNames')
+        if(!silent) message('n.TDpred inferred  inferred from TDpredNames')
         n.TDpred <- length(TDpredNames)
       } else n.TDpred <- 0
     } 
@@ -220,7 +222,7 @@ ctModel<-function(LAMBDA, type='omx',n.manifest = 'auto', n.latent='auto', Tpoin
   
   if(is.null(n.TIpred) || all(n.TIpred %in% 'auto')){
     if(!all(TIpredNames %in% 'auto')){
-      message('n.TIpred inferred  inferred from TIpredNames')
+      if(!silent) message('n.TIpred inferred  inferred from TIpredNames')
       n.TIpred <- length(TIpredNames)
     } else n.TIpred <- 0
   } 
@@ -288,9 +290,9 @@ ctModel<-function(LAMBDA, type='omx',n.manifest = 'auto', n.latent='auto', Tpoin
         counter <- 0 #then start filling with vector
         if(length(val) != length(mat) && length(val) !=1) stop(paste0(m,' needs ',length(mat),' values for ',nrow(mat),' * ',ncol(mat),' matrix, but has ',length(val)))
         if(length(val)==1 && length(mat) > 1) {
-          message(m,' specified via single value -- filling ',nrow(mat),' * ',ncol(mat),' matrix:')
+          if(!silent) message(m,' specified via single value -- filling ',nrow(mat),' * ',ncol(mat),' matrix:')
           val <- rep(val,length(mat))
-        } else message(paste0(m,' vector spec input rowwise into ',nrow(mat),' * ',ncol(mat),' matrix:'))
+        } else if(!silent) message(paste0(m,' vector spec input rowwise into ',nrow(mat),' * ',ncol(mat),' matrix:'))
         for(ri in 1:nrow(mat)){
           for(ci in 1:ncol(mat)){
             counter <- counter + 1
@@ -298,7 +300,7 @@ ctModel<-function(LAMBDA, type='omx',n.manifest = 'auto', n.latent='auto', Tpoin
           }
         }
         
-        print(mat,right=TRUE)
+        if(!silent) print(mat,right=TRUE)
         assign(m, mat)
       }
     }
