@@ -105,7 +105,7 @@ ctStanModel<-function(ctmodelobj, type='stanct',tipredDefault=TRUE){
           ctspec$transform[pi] <- 3
           ctspec$multiplier[pi] <- 2
           ctspec$offset[pi] <- -1
-          # if(ctspec$matrix[pi] %in% c('DIFFUSION')) ctspec$meanscale[pi] <-2
+          ctspec$meanscale[pi] <-10
         }
         if(ctspec$row[pi] == ctspec$col[pi]){
           ctspec$transform[pi] <- 1
@@ -270,6 +270,7 @@ ctStanModel<-function(ctmodelobj, type='stanct',tipredDefault=TRUE){
   # out$stationaryvarprior <- NA
   out$manifesttype <- rep(0,n.manifest)
   out$covmattransform <- 'rawcorr'
+  out$NOrdinalIntegrationPoints <- 9L
   
   return(out)
 }
