@@ -4,12 +4,6 @@ ctdataupdate<-function(forcerecompile=FALSE){
   continue <- readline()
   if(continue){
     set.seed(1)
-    
-  
-  
-
-
-  set.seed(1)
 
   Tpoints=10
   n.manifest=2
@@ -43,6 +37,7 @@ ctdataupdate<-function(forcerecompile=FALSE){
 
   save(ctstantestdat,file='.\\data\\ctstantestdat.rda')
 
+  ## now in zzz.R
   checkm<-ctModel(
     type='stanct',
     n.latent=2,n.TDpred=1,n.TIpred=1,n.manifest=2,
@@ -51,16 +46,16 @@ ctdataupdate<-function(forcerecompile=FALSE){
     DRIFT=c('dr1','dr12','dr21||||TI1','dr22'),
     DIFFUSION=c('diff11',0,'diff21','diff22||||TI1'),
     CINT=matrix(c('cint1||||TI1','cint2||||TI1'),ncol=1),
-    LAMBDA=diag(2),tipredDefault=FALSE)  
-  
-  ctstantestfit<-ctStanFit(ctsem::ctstantestdat,checkm,cores=1,
-    optimize = TRUE,optimcontrol=list(finishsamples=20,stochastic=T),nopriors=FALSE)
-  
-  ctstantestfit <- ctStanGenerateFromFit(ctstantestfit,nsamples = 20,fullposterior = TRUE)
-  
+    LAMBDA=diag(2),tipredDefault=FALSE)
+
+  ctstantestfit<-ctStanFit(ctstantestdat,checkm,cores=1,inits=0,
+    optimize = TRUE,optimcontrol=list(finishsamples=20,stochastic=T,tol=1e-5),priors=TRUE)
+
+  ctstantestfit <- ctStanGenerateFromFit(ctstantestfit,nsamples = 20,fullposterior = TRUE,cores=1)
+
   save(ctstantestfit,file='.\\data\\ctstantestfit.rda')
   
-  paths <- sort(Sys.glob(c("data/ctstantestfit.rda","data/ctstantestdat.rda")))
+  paths <- sort(Sys.glob(c("data/ctstantestfit.rda","data/ctstantestdat.rda"))) #
   tools::resaveRdaFiles(paths)
 }
 }
