@@ -15,7 +15,7 @@ if(identical(Sys.getenv("NOT_CRAN"), "true")& .Machine$sizeof.pointer != 4){
   effect <- rnorm(nsubjects, 5-baseline/3, 0.5)
   
   for(i in 1:nsubjects){
-    gm <- ctModel(Tpoints=ntimes,
+    gm <- suppressMessages(ctModel(silent=TRUE,Tpoints=ntimes,
       LAMBDA=matrix(c(1,0),1,2), 
       DRIFT= c(-1,1,
         0,-.5),
@@ -25,15 +25,15 @@ if(identical(Sys.getenv("NOT_CRAN"), "true")& .Machine$sizeof.pointer != 4){
       T0VAR = c(0,0,0,0),
       TDPREDMEANS = matrix(c(rep(0,9),1,rep(0,ntimes-10))),
       TDPREDEFFECT = matrix(c(0,effect[i]),2),
-      MANIFESTMEANS = baseline[i])
+      MANIFESTMEANS = baseline[i]))
     
-    d <- data.frame(ctGenerate(ctmodelobj = gm,n.subjects = 1,burnin = 0,dtmean = 1,logdtsd = 0))
+    d <- suppressMessages(data.frame(ctGenerate(ctmodelobj = gm,n.subjects = 1,burnin = 0,dtmean = 1,logdtsd = 0)))
     d$id <- i
     if(i==1) dat <- d else dat <- rbind(dat,d)
   }
   
   #regular bw effect approach
-  m <- ctModel(type='stanct',
+  m <- ctModel(silent=TRUE,type='stanct',
     LAMBDA=matrix(c(1,0),1,2), 
     DRIFT= c('drift',1,
       0,-0.5),
@@ -43,7 +43,7 @@ if(identical(Sys.getenv("NOT_CRAN"), "true")& .Machine$sizeof.pointer != 4){
     TDPREDEFFECT = matrix(c(0,'tdpredeffect|param|TRUE')))
   
   #manual bw effects
-  m2 <- ctModel(type='omx',Tpoints=3,
+  m2 <- ctModel(silent=TRUE,type='omx',Tpoints=3,
     LAMBDA=matrix(c(1,0,0,0),1,4), 
     DRIFT= c('drift',1,0,0,
       0,-0.5,0,0,
@@ -143,7 +143,7 @@ if(identical(Sys.getenv("NOT_CRAN"), "true")& .Machine$sizeof.pointer != 4){
     effect <- rnorm(nsubjects, 5-baseline/3, 0.5)
     
     for(i in 1:nsubjects){
-      gm <- ctModel(Tpoints=ntimes,
+      gm <- suppressMessages(ctModel(silent=TRUE,Tpoints=ntimes,
         LAMBDA=matrix(c(1,effect[i]),1,2), 
         DRIFT= c(-1,0,
           0,-.5),
@@ -153,15 +153,15 @@ if(identical(Sys.getenv("NOT_CRAN"), "true")& .Machine$sizeof.pointer != 4){
         T0VAR = c(0,0,0,0),
         TDPREDMEANS = matrix(c(rep(0,9),1,rep(0,ntimes-10))),
         TDPREDEFFECT = matrix(c(0,1),2),
-        MANIFESTMEANS = baseline[i])
+        MANIFESTMEANS = baseline[i]))
       
-      d <- data.frame(ctGenerate(ctmodelobj = gm,n.subjects = 1,burnin = 0,dtmean = 1,logdtsd = 0))
+      d <- suppressMessages(data.frame(ctGenerate(ctmodelobj = gm,n.subjects = 1,burnin = 0,dtmean = 1,logdtsd = 0)))
       d$id <- i
       if(i==1) dat <- d else dat <- rbind(dat,d)
     }
     
     #regular bw effect approach
-    m <- ctModel(type='stanct',
+    m <- ctModel(silent=TRUE,type='stanct',
       LAMBDA=matrix(c(1,'tdpredeffect|param|TRUE'),1,2), 
       DRIFT= c('drift',0,
         0,-0.5),
@@ -171,7 +171,7 @@ if(identical(Sys.getenv("NOT_CRAN"), "true")& .Machine$sizeof.pointer != 4){
       TDPREDEFFECT = matrix(c(0,1)))
     
     #manual bw effects
-    m2 <- ctModel(type='omx',Tpoints=3,
+    m2 <- ctModel(silent=TRUE,type='omx',Tpoints=3,
       LAMBDA=matrix(c(1,'state[4]',0,0),1,4), 
       DRIFT= c('drift',0,0,0,
         0,-0.5,0,0,
@@ -268,7 +268,7 @@ if(identical(Sys.getenv("NOT_CRAN"), "true")& .Machine$sizeof.pointer != 4){
     effect <- -log1p(exp(-raweffect))
     
     for(i in 1:nsubjects){
-      gm <- suppressMessages(ctModel(Tpoints=ntimes,
+      gm <- suppressMessages(ctModel(silent=TRUE,Tpoints=ntimes,
         LAMBDA=matrix(1), 
         DRIFT= c(effect[i]),
         T0MEANS = c(t0m[i]),
@@ -283,12 +283,12 @@ if(identical(Sys.getenv("NOT_CRAN"), "true")& .Machine$sizeof.pointer != 4){
     }
     
     #regular bw effect approach
-    m <- ctModel(type='stanct',
+    m <- ctModel(silent=TRUE,type='stanct',
       CINT='cint',MANIFESTMEANS=0,
       LAMBDA=matrix(1),DRIFT='drift|-log1p_exp(-param)|TRUE')
     
     #manual bw effects
-    m2 <- ctModel(type='omx',Tpoints=3,
+    m2 <- ctModel(silent=TRUE,type='omx',Tpoints=3,
       LAMBDA=matrix(c(1,0,0),ncol=3), 
       DRIFT= c('-log1p_exp(-state[2])',0,0,
         0,-1e-6,0,
@@ -388,7 +388,7 @@ if(identical(Sys.getenv("NOT_CRAN"), "true")& .Machine$sizeof.pointer != 4){
     effect <- log1p(exp(raweffect))
     
     for(i in 1:nsubjects){
-      gm <- ctModel(Tpoints=ntimes,
+      gm <- suppressMessages(ctModel(silent=TRUE,Tpoints=ntimes,
         LAMBDA=matrix(1), 
         DRIFT= -1,
         T0MEANS = c(t0m[i]),
@@ -396,22 +396,22 @@ if(identical(Sys.getenv("NOT_CRAN"), "true")& .Machine$sizeof.pointer != 4){
         MANIFESTVAR = 0.5,
         T0VAR = c(0),
         CINT = baseline[i],
-        MANIFESTMEANS=0)
+        MANIFESTMEANS=0))
       
-      d <- data.frame(ctGenerate(ctmodelobj = gm,n.subjects = 1,burnin = 0,dtmean = .1,logdtsd = 0))
+      d <- suppressMessages(data.frame(ctGenerate(ctmodelobj = gm,n.subjects = 1,burnin = 0,dtmean = .1,logdtsd = 0)))
       d$id <- i
       if(i==1) dat <- d else dat <- rbind(dat,d)
     }
     
     #regular bw effect approach
-    m <- ctModel(type='stanct',
+    m <- ctModel(silent=TRUE,type='stanct',
       T0MEANS='t0m|param',
       MANIFESTVAR=.5,
       MANIFESTMEANS=0,CINT='cint|param',
       LAMBDA=matrix(1),DIFFUSION='diffusion|log1p_exp(param)|TRUE')
     
     #manual bw effects
-    m2 <- ctModel(type='omx',Tpoints=3,
+    m2 <- ctModel(silent=TRUE,type='omx',Tpoints=3,
       LAMBDA=matrix(c(1,0,0),ncol=3), 
       DRIFT= c('drift',0,0,
         0,-1e-12,0,
@@ -521,7 +521,7 @@ if(identical(Sys.getenv("NOT_CRAN"), "true")& .Machine$sizeof.pointer != 4){
     effect <- log1p(exp(raweffect))
     
     for(i in 1:nsubjects){
-      gm <- ctModel(Tpoints=ntimes,
+      gm <- suppressMessages(ctModel(silent=TRUE,Tpoints=ntimes,
         LAMBDA=matrix(1), 
         DRIFT= -1,
         T0MEANS = c(t0m[i]),
@@ -529,22 +529,22 @@ if(identical(Sys.getenv("NOT_CRAN"), "true")& .Machine$sizeof.pointer != 4){
         DIFFUSION = 0.5,
         T0VAR = c(0),
         CINT = baseline[i],
-        MANIFESTMEANS=0)
+        MANIFESTMEANS=0))
       
-      d <- data.frame(ctGenerate(ctmodelobj = gm,n.subjects = 1,burnin = 0,dtmean = .1,logdtsd = 0))
+      d <- suppressMessages(data.frame(ctGenerate(ctmodelobj = gm,n.subjects = 1,burnin = 0,dtmean = .1,logdtsd = 0)))
       d$id <- i
       if(i==1) dat <- d else dat <- rbind(dat,d)
     }
     
     #regular bw effect approach
-    m <- ctModel(type='stanct',
+    m <- ctModel(silent=TRUE,type='stanct',
       T0MEANS='t0m|param',
       DIFFUSION=.5,
       MANIFESTMEANS=0,CINT='cint|param',
       LAMBDA=matrix(1),MANIFESTVAR='errsd|log1p_exp(param)|TRUE')
     
     #manual bw effects
-    m2 <- ctModel(type='omx',Tpoints=3,
+    m2 <- ctModel(silent=TRUE,type='omx',Tpoints=3,
       LAMBDA=matrix(c(1,0,0),ncol=3), 
       DRIFT= c('drift',0,0,
         0,-1e-12,0,
