@@ -2,6 +2,7 @@ if(identical(Sys.getenv("NOT_CRAN"), "true")& .Machine$sizeof.pointer != 4){
   
   library(ctsem)
   library(testthat)
+  cores=2
   
   context("ukfpopcheck") 
   
@@ -10,7 +11,7 @@ if(identical(Sys.getenv("NOT_CRAN"), "true")& .Machine$sizeof.pointer != 4){
     Tpoints<-10
     n.latent=2
     n.manifest=3
-    nsubjects=60
+    nsubjects=160
     burnin=3
     dtmat = matrix(exp(rnorm(burnin+Tpoints-1,-.3,.5)),1)
     par1<-rnorm(nsubjects,-.3,.8)
@@ -48,62 +49,34 @@ if(identical(Sys.getenv("NOT_CRAN"), "true")& .Machine$sizeof.pointer != 4){
     m2<-ctModel(type='omx',n.latent=2,n.manifest=n.manifest,Tpoints=Tpoints,
       MANIFESTMEANS=matrix(0,n.manifest),
       CINT=matrix(paste0('cint',1:gm$n.latent)),
-      TRAITVAR='auto',
       LAMBDA=gm$LAMBDA
     )
     
     
     
-    #bayesian / ukf ctsem
+    #fit 1
     sm1 <- ctStanModel(m1)
     sm1$pars$indvarying <- FALSE
-
-    sf1 <- ctStanFit(cd,sm1,iter=200,
-      optimize=TRUE,verbose=0,
-      optimcontrol=list(finishsamples=50),
-      nlcontrol=list(nldynamics=FALSE))
-
-    
-    sf1d=sf1$stanfit$transformedparsfull$pop_DRIFT[1,1:2,1:2]#matrix(sf1$stanfit$transformedpars_old[grep('pop_DRIFT',rownames(sf1$stanfit$transformedpars_old)),'mean'],4,4)[1:2,1:2]
+    sf1 <- ctStanFit(cd,sm1,cores=cores,verbose=0)
+    sf1d=sf1$stanfit$transformedparsfull$pop_DRIFT[1,1:2,1:2]
     sf1ll=sf1$stanfit$optimfit$value
     
+    #fit 2
     sm2 <- ctStanModel(m2)
     sm2$pars$sdscale <- .2
-    
-    sf2 <- ctStanFit(cd,sm2,
-      optimize=T,verbose=0)
-
-    sf2d=sf2$stanfit$transformedparsfull$pop_DRIFT[1,1:2,1:2]# matrix(sf2$stanfit$transformedpars_old[grep('pop_DRIFT',rownames(sf2$stanfit$transformedpars_old)),'mean'],4,4)[1:2,1:2]
+    sf2 <- ctStanFit(cd,sm2,cores=cores)
+    sf2d=sf2$stanfit$transformedparsfull$pop_DRIFT[1,1:2,1:2]
     sf2ll=sf2$stanfit$optimfit$value
     
-    if(1==99){
-    summary(sf2)$popmeans
-    sf2$stanfit$transformedparsfull$popcov[1,,]
-    sf1$stanfit$transformedparsfull$pop_T0cov[1,,]
-    }
+    testthat::expect_equivalent(sf1ll,sf2ll,tol=1e-3)
     
-    for(i in 1:4){
-      for(j in 1:4){
-        if(i==j) testthat::expect_equivalent(
-             sqrt(sf1$stanfit$transformedparsfull$pop_T0cov[1,i,j])/ sqrt(sf2$stanfit$transformedparsfull$popcov[1,i,j]),
-          1,
-          tol=.15)
-        if(i>j) testthat::expect_equivalent(  cov2cor(    sf1$stanfit$transformedparsfull$pop_T0cov[1,,])[i,j],
-          cov2cor(sf2$stanfit$transformedparsfull$popcov[1,,])[i,j],.1)
-      }
-    }
+    testthat::expect_equivalent(sf1$stanfit$transformedparsfull$pop_T0cov,
+      sf2$stanfit$transformedparsfull$popcov,tol=1e-1)
     
-    dvec=c('sf1d','sf2d')
-    llvec=c('sf1ll','sf2ll')
-    
-    sapply(dvec,get,envir=sys.frame(sys.parent(0)))
-    sapply(llvec,get,envir=sys.frame(sys.parent(0)))
-    
-    for(di in 2:length(dvec)){
-      expect_equivalent(get(dvec[di]),get(dvec[di-1]),tol=1e-1)
-      expect_equivalent(get(llvec[di]),get(llvec[di-1]),tol=1e-3)
-      expect_equivalent(get(dvec[di]),c(-.4,0,0,-.4),tol=.1)
-    }
+    testthat::expect_equivalent(cov2cor(sf1$stanfit$transformedparsfull$pop_T0cov[1,,]),
+      cov2cor(sf2$stanfit$transformedparsfull$rawpopcov[1,,]),tol=1e-2)
+
+    testthat::expect_equivalent(sf1d,sf2d,tol=1e-2)
     
   })
   
@@ -124,7 +97,6 @@ if(identical(Sys.getenv("NOT_CRAN"), "true")& .Machine$sizeof.pointer != 4){
       d=suppressMessages(ctGenerate(m,n.subjects = 1,burnin = 0,wide = FALSE,dtmean = dt))[,-1]
       if(si==1) dat=cbind(si,d) else dat=rbind(dat,cbind(si,d))
     }
-    
     colnames(dat)[1]='id'
     
     dtm <- ctModel(LAMBDA=diag(1), type='stanct',
@@ -150,7 +122,7 @@ if(identical(Sys.getenv("NOT_CRAN"), "true")& .Machine$sizeof.pointer != 4){
     dtf2=ctStanFit(datalong = dat,ctstanmodel = dtm2,optimize = TRUE)
     s2=summary(dtf2,parmatrices = F,priorcheck = F,residualcov = F)
     
-    # expect_equivalent(c(s1$popmeans[,1],s1$popsd[,1]),s2$popmeans[,1],tol=1e-2)
+    testthat::expect_equivalent(s1$ll,s2$ll,tol=1e-3)
     testthat::expect_equivalent(sort(dtf2$stanfit$rawest),sort(dtf$stanfit$rawest),tol=1e-3) #sorting is an ugly hack! could improve...
     
   })
